@@ -252,8 +252,8 @@ class GitLayerIndex(object):
         f.is_error404 = uri == self.ERROR_404_FILE
         f.is_base = name.startswith('_')
         f._modtime = modtime
-        f.is_html = f.do_jinja and not f.is_error401 and not f.is_error404 \
-            and not f.is_base
+        f.is_html = (f.do_jinja or f.do_markdown) and not f.is_error401 \
+            and not f.is_error404 and not f.is_base
         if (f.do_markdown or f.do_jinja) and f.large:
             # file is too large to bother rendering
             estr = 'error! not pre-rendering file as it is too large: {}'
